package com.huiju.estateagents.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.entity.TaSalesBatch;
import com.huiju.estateagents.mapper.TaSalesBatchMapper;
import com.huiju.estateagents.service.ITaSalesBatchService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 销售批次表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@Service
public class TaSalesBatchServiceImpl extends ServiceImpl<TaSalesBatchMapper, TaSalesBatch> implements ITaSalesBatchService {

    private Logger logger = LoggerFactory.getLogger(TaSalesBatchServiceImpl.class);

    @Autowired
    private TaSalesBatchMapper taSalesBatchMapper;

    @Override
    public IPage<TaSalesBatch> selectByCondition(IPage<TaSalesBatch> page, String salesBatchName, String buildingId, Integer status, Integer orgId) {
        return taSalesBatchMapper.selectByCondition(page, salesBatchName, buildingId, status, orgId);
    }

    @Override
    public ResponseBean delSalesBatchList(Integer orgId, List<TaSalesBatch> taSalesBatchList) {
        ResponseBean responseBean = new ResponseBean();
        Integer count = taSalesBatchMapper.countPreSelectRecord(orgId, taSalesBatchList);
        if (count > 0) {
            responseBean.addError("已有用户预选，请先删除预选记录。");
            return responseBean;
        }
        taSalesBatchMapper.updateSalesBatchStatus(orgId, taSalesBatchList);
        return responseBean;
    }

    /**
     * 获取通知信息
     *
     * @param salesBatchId 销售批次ID
     * @return
     */
    @Override
    public ResponseBean getNoticeInfo(Integer salesBatchId) {
        logger.info("getNoticeInfo 接收参数：saleBatchId：{}", salesBatchId);

        ResponseBean responseBean = new ResponseBean();

        TaSalesBatch salesBatch = getById(salesBatchId);
        if (salesBatch == null) {
            responseBean.addError("未查询到数据");
            return responseBean;
        }

        List<String> noticeList = new ArrayList<>();
        // 当前时间万余预选结束时间
        if (DateUtils.isAfter(salesBatch.getPreselectionEndTime())) {
            noticeList.add("预选已结束，请关注下轮预选");
            responseBean.addSuccess(noticeList);
            return responseBean;
        }

        // 当前时间早于预选开始时间
        if (DateUtils.isBefore(salesBatch.getPreselectionStartTime())) {
            String str = DateUtils.diffTime(DateUtils.timeToLocalDateTime(salesBatch.getPreselectionStartTime()), LocalDateTime.now());
            noticeList.add("距离预选开始还有" + str);
            responseBean.addSuccess(noticeList);
            return responseBean;
        }

        // 当前时间在预选时间内
        if (DateUtils.isAfter(salesBatch.getPreselectionStartTime()) && DateUtils.isBefore(salesBatch.getPreselectionEndTime())) {
            String str = DateUtils.diffTime(LocalDateTime.now(), DateUtils.timeToLocalDateTime(salesBatch.getPreselectionEndTime()));
            noticeList.add("距离预选结束还有" + str);
        }

        // 获取房源预选数量
        Map<String, Long> result = taSalesBatchMapper.getTotalHousesAndHeat(salesBatchId);
        if (result != null) {
            Long totalHouses = result.get("totalHouses");
            Long totalRealHeat = result.get("totalRealHeat");
            if (totalRealHeat != null && totalRealHeat > 0) {
                noticeList.add("当前" + totalHouses + "套房源已有" + totalRealHeat + "人成功预选 ");
            }
        }
        responseBean.addSuccess(noticeList);
        return responseBean;
    }
}
